import com.partnersoft.data.RandomLib;
import com.partnersoft.v3x.apps.Staker.domain.UnitAtALocation;
import com.partnersoft.v3x.apps.Staker.domain.UnitOnASpan;


/**
* What does this script do?
* -------------------------
* This script goes through all staked location units in a job, generates and assigns
* new guids to the "Multispeak_FeatureID" and "Multispeak_ElementID" staked unit info
* fields if that field is null or empty. This is needed for the MultiSpeak interface.
*
* @author Jaim Ahmed, 05/10/2016
*/

//-- staked unit info fields --//
idFields = [
    "MultiSpeak_assemblyID",
    "MultiSpeak_featureID"
];


//-- methods --//
/**
 * Given a staked unit (a UnitAtALocation object) and a field name, this
 * method generates a new guid and assign it to the field.
 */
private String setStakedUnitId(UnitAtALocation stakedUnit, String fieldName) {
    String currentValue = stakedUnit.getInfo().get(fieldName);
    if (currentValue == null || currentValue.trim().isEmpty()) {
        String guid = "New" + RandomLib.randomGuid();
        //log.info("Staked unit: " + stakedUnit.getUnit().getName() + ": setting staked unit field \"" + fieldName + "\" to " + guid);
        stakedUnit.getInfo().setFieldValue(fieldName, guid);
    }
}


// ******** script starts here ************
log.info("Setting MultiSpeak ID fields for staked units for job: " + job);

// check job type
if (!("normal".equals(jobType) || "hub job".equals(jobType))) {
    log.info("Not setting staked unit ID fields for job " + job);
    return;
}


//gather up all the units in a list, for efficiency purposes and the go through
//the fields and create and assign new guids for that unit.
listOfAllUnits = new ArrayList();
for (location in job.listLocations()) {
	listOfAllUnits.addAll(location.getUnits());
}

for(stakedUnit in listOfAllUnits) {
	for(idField in idFields) {
		setStakedUnitId(stakedUnit,idField);
	}
}

// done
log.info("Done setting MultiSpeak ID fields for staked units in job: " + job); 
