/**
 * By default, script returns mouse hover coordinates in
 * Degrees, Minutes Seconds. If a point item is selected,
 * then both the hover coordinates and selection coordinates
 * are returned in lon-lat order. If a line item is selected,
 * then the message "selected is line" is displayed along with
 * hover coordinates.
 *
 * IF YOU WANT DECIMAL DEGREES INSTEAD OF DEG,MIN,SEC
 * CHANGE LINE 17
 **/
import com.partnersoft.maps.app.MapApp;
import com.partnersoft.geometry.projection.CoordinateSystem;
import com.partnersoft.geometry.projection.Projection;
import com.partnersoft.geometry.lonlat.LonlatPoint;
import com.partnersoft.geometry.projection.ProjectionConstants;

decimalDegrees = false;

coordSystem = app.getSpace().getCoordinateSystem();
if (coordSystem == null) {
	// Bad configuration. No coordinate system is set.
	return;
}
projection = coordSystem.getProjection();
if (projection == null || projection == ProjectionConstants.NULL_PROJECTION) {
	// Bad configuration. Coordinate system projection will fail.
	return;
}

// reverse project to lonlat
lonlat = coordSystem.reverseProject(x, y);

//Get A Selection Point
selPoint = app.logic.selectionLogic.getSelectedItem();
if (selPoint != null){
	selX = selPoint.getLocation().getX();
	selY = selPoint.getLocation().getY();
	selLonLat = coordSystem.reverseProject(selX, selY);
	}

// THIS SECTION RETURNS DEGREES, MINUTES, SECONDS
if (decimalDegrees==false){
	if (selPoint == null){
	  // nothing selected. Return hover coords only.
	  return lonlat.toString();
	}
	else if (selPoint.isLine()){
	  // selected mapDataItem is a line. Cannot return single point coordinate.
	  return "(hover: "+(lonlat.toString())+") (selected: line)";
	}
	else{
	  // calcluate last selected data item coord
	  return "(hover: "+(lonlat.toString())+") (selected: "+(selLonLat.toString())+")";
	}
}

//THIS SECTION RETURNS DECIMAL DEGREES TO 6 DECIMAL PLACES.
//NEED LONGER? CHANGE LINES 68 AND 69

else{
	// return default string representation (degree, minute, second)
	xDec = String.format("%.6f",lonlat.getLongitude());
	yDec = String.format("%.6f",lonlat.getLatitude());

	if (selPoint == null) {
	  // nothing selected. Return hover coords only.
	  return xDec+", "+yDec;
	}
	else if (selPoint.isLine()){
	  // selected mapDataItem is a line. Cannot return single point coordinate.
	  return "(hover: "+xDec+", "+yDec+") (selected: line)";
	}
	else{
	  // calcluate last selected data item coord
	  selXDec = String.format("%.6f",selLonLat.getLongitude());
	  selYDec = String.format("%.6f",selLonLat.getLatitude());
	  return "(hover: "+xDec+", "+yDec+")  (selected: "+selXDec+", "+selYDec+")";
	}
}