import java.util.ArrayList;
import com.partnersoft.system.SystemServices;
import com.partnersoft.net.NetworkService;
import com.partnersoft.data.*;
import com.partnersoft.io.vfs.*;

/**
 * Creates a special mysql config file to use while running upgrade_tables.
 * Allows us to run the new mysql binary in the MasterInstall,
 * using the data in the CentralHub.
*/


module = SystemServices.moduleManager().moduleNamed("MySQL");

// set up the files & directories that will be needed
FileVfs hubVfs = getPartnerHubVfs();

// use the CentralHub for logs & data
centralHub_logDirectory = hubVfs.directoryFor("CentralHub/logs/modules/MySQL");
centralHub_mysqlDataDir = hubVfs.directoryFor("CentralHub/data/MySQL");

// the rest from the MasterInstall
moduleTempDir = module.getTempDirectory();
if(!VfsLib.directoryExists(moduleTempDir))
	moduleTempDir.make();

configFile = moduleTempDir.fileFor("partner.cnf");
mySqlBaseDir = module.getDirectory().directoryFor("os/windows/applications/MySQL/");


templateVariables = createTemplateVariables();

module.createFileFromTemplate("partner_cnf", configFile, templateVariables);

/**
 * Set up the variables that will be used by the string template
 * @return a Naming of variables to be passed to the string template
 */
private Naming<Object> createTemplateVariables() {
	Naming<Object> templateVariables = new Naming<Object>();
		
	templateVariables.put("PORT_NUMBER", "" + NetworkService.HUB_MYSQL.getPortNumber());
	templateVariables.put("BASE_DIR", replaceBackslashesFor(mySqlBaseDir));
	templateVariables.put("DATA_DIR", replaceBackslashesFor(centralHub_mysqlDataDir));
	templateVariables.put("LOGS_DIR", replaceBackslashesFor(centralHub_logDirectory));
	templateVariables.put("TEMP_DIR", replaceBackslashesFor(moduleTempDir));
	
	configDir = module.getConfigDirectory();
	if(VfsLib.directoryExists(configDir)) {
		pathString = configDir.toFile().getAbsolutePath();
		String includeCustomConf = "!includedir \"" + pathString + "\"";
		templateVariables.put("INCLUDE_CONFIG_DIR", includeCustomConf);
	}
	
	return templateVariables;
}

/**
 * Create a new Vfs rooted above the MasterInstall and CentralHub directories.
 * @return a Vfs above both MI and CH
 */
private FileVfs getPartnerHubVfs() {
	//this guy is gonna be running out of the master install, we need to list directories in CentralHub/data/MySQL
	//get the vfs that we are running in
	Vfs currentVfs = SystemServices.vfs();

	//get the parent of master install
	Path hubPath = ((Path)currentVfs.getAbsolutePath()).getParent();
	String hubPathString = hubPath.toFileString();
	//create a new vfs above both master install and central hub
	FileVfs hubVfs = new FileVfs(hubPathString);
	return hubVfs;
}

private String replaceBackslashesFor(VfsNode node) {
	return node.toFile().getAbsolutePath().replace('\\', '/');
}
