import com.partnersoft.system.SystemServices;
import com.partnersoft.io.vfs.*;
import com.partnersoft.data.Path;
/**
 * Search scripts and xml configuration files for references to methods projectFeet and reverseFeet.
 * Writes results to file and displays them in workbench log.
 */
		
// some top level directories to skip
excludeDirs = new ArrayList();
excludeDirs.add("data");
excludeDirs.add("maps");
excludeDirs.add("logs");
excludeDirs.add("archive");
excludeDirs.add("os");
excludeDirs.add("temp");
excludeDirs.add("tmp");
excludeDirs.add("update");
excludeDirs.add("modules");

//some modules should not be searched
excludeModules = new ArrayList();
excludeModules.add("MySQL");
excludeModules.add("MySQLJdbcDriver");
excludeModules.add("FOP");
excludeModules.add("Jython");
excludeModules.add("PHP");
excludeModules.add("Apache");
excludeModules.add("UpgradeService");

rootDir = SystemServices.vfs().directoryFor(".");
resultsFile = rootDir.fileFor("data/InvalidProjectionMethods.txt");

coordDisplayPath = new Path("config/customer/mapspaces/Standard");
coordinateDisplayFileName = "Coordinate Display.bsh"

// make a list of directories to search, excluding those in the list defined above
dirsToCheck = new ArrayList<VfsDirectory>();
for(dir in rootDir.listDirectories()) {
	if(!excludeDirs.contains(dir.getName())) {
		dirsToCheck.add(dir);
	}
}

//make a list of module directories to search, excluding those in the list above
modulesToCheck = new ArrayList<VfsDirectory>();
modulesDir = SystemServices.vfs().directoryFor("modules");
for( configDir in modulesDir.listDirectories()) {
	for(moduleDir in configDir.listDirectories() ) {
		if(!excludeModules.contains(moduleDir.getName())) {
			modulesToCheck.add(moduleDir);
		}
	}
}

// combine the list of module directories with the original directory list
dirsToCheck.addAll(modulesToCheck);

// counter for the number of references found
totalInstances = 0;
/*
 * will find instances like:
 * lonlat = projection.reverseFeet(x, y);
 * or
 * lonlat = projection.projectFeet(x, y);
 */
regexList = new ArrayList<String>();
regexList.add(".*\\.projectFeet.*");
regexList.add(".*\\.reverseFeet.*");

instances = new HashMap<VfsFile, StringBuilder>();

log.info("Searching python files.");
searchExtensionType(".py", regexList);
log.info("Searching groovy files.");
searchExtensionType(".groovy", regexList);
log.info("Searching beanshell files.");
searchExtensionType(".bsh", regexList);

writeResults();
workbenchApp.getLogic().getFileLogic().edit(resultsFile);

def void writeResults() {
	log.info("Found " + totalInstances + " places that you need to check.");
	log.info("Results written to file:" + System.lineSeparator() + resultsFile);
	
	StringBuilder allResults = new StringBuilder();
	allResults.append("The following files contain calls to methods that no longer exist, and will break if used.");
	allResults.append(System.lineSeparator());
	
	for(VfsFile file in instances.keySet()) {
		fileResults = instances.get(file);
		allResults.append(System.lineSeparator());
		allResults.append(file);
		allResults.append(fileResults.toString());
	}
	
	resultsFile.writeText(allResults.toString());
}

def void searchExtensionType(String extension, List<String> regexList) {
	for(dir in dirsToCheck) {
		fileList = dir.findFilesWithExtension(extension);
		for(file in fileList) {

			// omit config/customer/mapspaces/Standard/scripts/Coordinate Display.bsh, we will manually replace it
			if(coordinateDisplayFileName.equals(file.getName())) {
				if(coordDisplayPath.isAncestorOf(file.getPath())) 
					continue;				
			}
			
			lines = file.readTextAsLines();
			int lineNumber = 1;
			for(line in lines) {
				for(regex in regexList) {
					if(line.matches(regex)) {
						
						StringBuilder results = instances.get(file);
						if(results == null) {
							results = new StringBuilder();
							instances.put(file, results);
						}						
						totalInstances++;
						results.append(System.lineSeparator());
						results.append("\tLine: ");
						results.append(lineNumber);
						results.append(System.lineSeparator());
						results.append("\t");
						results.append(line);
						results.append(System.lineSeparator());
					}
				}
				lineNumber++;
			}
		}
	}
}

