import com.partnersoft.modules.upgradeservice.compatibility.StakerConfigDatabase;


database = new StakerConfigDatabase();
		
database.open();

featureField = database.getUnitDefinitionField("feature");

if("ERROR".equals(featureField)) {
	criticals.add("Could not determine what unit field is used for feature!");
	database.close();
	return;
}

connection = database.getConnection();

updateUnitRecords();

checkForStreetLightInPicklist();

database.close();

log.info("Finished changing poleLight to streetLight.");

private void checkForStreetLightInPicklist() {
	log.info("Checking to ensure streetLight is an option in the picklist...");
	
	// examine the feature field, make sure it's a picklist
	fieldType = connection.oneFieldQuery("select type from unitfields where fieldName = \'" + featureField + "\'")
	if(!"lookup".equalsIgnoreCase(fieldType)) {
		log.error("The field for feature is not a picklist, you need to set it up!");
		warnings.add("The field for feature is not a picklist, you need to set it up!");
		return;
	}
	
	// good, so it's a picklist.  Now let's get the name of the picklist
	String picklistName = connection.oneFieldQuery("select picklistName from unitfields where fieldName = \'" + featureField + "\'");
	
	// get the picklist ID
	int picklistId = database.idForPicklist(picklistName);
	
	if(picklistId == 0) {
		log.error("Could not determine the picklistId for the picklist named " + picklistName + "- You should setup the picklist for features!");
		warnings.add("Could not determine the picklistId for the picklist named " + picklistName + "- You should setup the picklist for features!");
		return;
	}
	
	// determine if there is an entry for streetLight in the picklist
	Object result = connection.oneFieldQuery("select id from picklistvalues where label LIKE \'%streetLight%\' and picklist = \'" + picklistId + "\'");
	if (result == null || "ERROR".equals(result)) {
		log.warn("Did not find an entry for streetLight in the picklist named " + picklistName + ", will create one...");
		String insertStatement = "insert into picklistvalues (picklist, label, accountingCode) values (?, ?, ?)";
		connection.execute(insertStatement, picklistId, "streetLight", "0");
		log.info("Finished adding streetLight to the picklist!");
	}else
		log.info("Picklist for feature already contains streetLight, moving on...");	
		
	// determine if there is an entry for poleLight, if so, delete it 
	result = connection.oneFieldQuery("select id from picklistvalues where label LIKE \'%poleLight%\' and picklist = \'" + picklistId + "\'");
	if (result == null || "ERROR".equals(result)) {
		log.info("Did not find an entry for poleLight in the picklist named " + picklistName + ", no need to delete it...");		
	}else {
		String deleteStatement = "delete from picklistvalues where label LIKE '%poleLight%' and picklist = \'" + picklistId + "\'";
		connection.execute(deleteStatement);
		log.info("Finished deleting poleLight from the picklist!");
	}
}

private void updateUnitRecords() {
	log.info("Updating unit records...");
	
	results = connection.oneColumnQuery("SELECT id FROM unitmaster WHERE " + featureField + " LIKE \'%poleLight%\'");
	
	String updateQuery = "update unitmaster set " + featureField + " = ? where id = ?";
	for(result in results) {
		connection.execute(updateQuery, "streetLight", result);
	}
	
	log.info("Updated " + results.size() + " unit records.");
}