import com.partnersoft.modules.upgradeservice.compatibility.StakerConfigDatabase;
import com.partnersoft.data.ConversionLib;
import com.partnersoft.system.*;
import com.partnersoft.v3x.data.*;
import com.partnersoft.v3x.gui.*;
import com.partnersoft.formats.tof.*;
import org.jcon.data.*;


fieldName = "Station_ID";
fieldLabel = "Station ID:"
fieldDescription = "Mapping interface field";
fieldDataType = "string";

// will use the Pole_ID field to find what tab to put Station_ID on.
poleFieldName = "Pole_ID";


database = new StakerConfigDatabase();

database.open();
fieldId = -1;

if(database.locationFieldExists(fieldName)) {
	log.info(fieldName + " already exists.");
	fieldId = database.idForLocationField(fieldName);
}else {
	log.info("Creating location field named: " + fieldName);
	fieldId = database.addLocationField(fieldName, fieldLabel, fieldDescription, fieldDataType, null);
	addToLocationFields();
}

log.info("fieldID is: " + fieldId);


tabName = getTabName();

if("ERROR".equals(tabName)) {
	log.error("Could not find which tab to use!");
	warnings.add("You'll have to manually add " + fieldName + " to the correct Location tab.");
}else {
	log.info("Adding " + fieldName + " to tab: " + tabName);
	// add the field to the tab
	database.addLocationFieldToTab(fieldName, fieldLabel, tabName);

	// add to the tof file
	addToEditorFile();
}


database.close();
log.info("Finished adding " + fieldName + " to Staker config.");

private String getTabName() {
	log.info("Trying to find what tab " + poleFieldName + " is on...");
	String tabName = "ERROR";
	
	poleFieldId = database.idForLocationField(poleFieldName);
	
	if(!poleFieldId) {
		log.warning("Couldn't find fieldId for " + poleFieldName + "!");
		return tabName;
	}
	
	log.info("fieldID for " + poleFieldName + " is: " + poleFieldId);
	
	connection = database.getConnection();
	
	// get tab for pole field
	whichTabQuery = "SELECT tabID FROM headerfields_tabs_fields WHERE fieldID = " + poleFieldId;
	
	// may be dead/invalid entries in the headerfields_tabs_fields table
	results = connection.oneColumnQuery(whichTabQuery);
	
	// make sure the tab has a label, and it is location level
	for(result in results) {
		tabFieldId = ConversionLib.forceToInt(result);
		log.info("Checking validity of tabFieldId: " + tabFieldId);
	
		tabName = connection.oneFieldQuery("select label from headerFields_tabs where id = " + tabFieldId);
		
		if("ERROR".equals(tabName )) {
			log.warn("Dead entry for headerfields_tabs_fields:id " + poleFieldId);
			continue;
		}
	
		level = connection.oneFieldQuery("select level from headerFields_tabs where id = " + tabFieldId);
	
		// Found it
		if("Location".equalsIgnoreCase(level)) {
			break;
		}
	}

	return tabName;
}

private void addToLocationFields() {
	fileString = "v3x/Shared/config/partner/LocationFields.tof";
	file = SystemServices.vfs().fileFor(fileString);
	
	fieldDefs = TofLib.readObjectFrom(file);
	
	fieldDef = new FieldDef();
	fieldDef.setDisplayName(fieldLabel);
	fieldDef.setDescription(fieldDescription);
	fieldDef.setType(String.class);
	
	fieldDefs.put(fieldName, fieldDef);
	TofLib.writeObjectTo(fieldDefs, file);
}

private void addToEditorFile() {
	guiFileString = "v3x/FieldDesigner/config/partner/LocationEditorConfig.tof";
	guiFile = SystemServices.vfs().fileFor(guiFileString);
	editTabConfigs = TofLib.readObjectFrom(guiFile);
	tabby = getEditTabConfig(editTabConfigs);

	if(tabby == null ) {
		log.error("Couldn't find tab named " + tabName + " in " + guiFileString);
		return;
	}
	newField = new FieldBlank();
	newField.setFieldName(fieldName);
	newField.setLabel(fieldLabel);
	newField.setControlName("stringSpecifier");
	parameters = new HashMap();
	parameters.put("labelColor", "black");
	newField.setParameters(parameters);
	
	
	tabby.getFieldBlanks().add(newField);
	
	TofLib.writeObjectTo(editTabConfigs, guiFile);
}

private EditTabConfig getEditTabConfig(List<EditTabConfig> editTabConfigs) {
	for(tabConfig in editTabConfigs)
		if(tabName.equals(tabConfig.getName()))
			return tabConfig;
	return null;
}