import com.partnersoft.modules.upgradeservice.compatibility.StakerConfigDatabase;
import com.partnersoft.system.*;
import com.partnersoft.data.*;
import com.partnersoft.v3x.data.*;
import com.partnersoft.v3x.gui.*;
import com.partnersoft.formats.tof.*;
import org.jcon.data.*;
import javax.swing.JOptionPane;


fileString = "v3x/Shared/config/partner/UnitFields.tof";
file = SystemServices.vfs().fileFor(fileString);

unitFields = TofLib.readObjectFrom(file);
fieldDefs = CaseInsensitiveTreeMap.ensureInsensitive(unitFields);

ambiguousUnitPhaseField = false;
unitPhaseFieldName = getUnitPhaseFieldName();

newFields = createNewFieldDefs();
addNewFieldsToDatabase();
addNewFieldsToTof();
updateLocationUnitFieldsFile();

if(ambiguousUnitPhaseField) 
	warnUser();

log.info("Finished creating staked unit info fields.");

private void warnUser() {
	message = new StringBuilder();
	message.append("Could not find a unit info field named \"phase\" or \"unitPhase\".");
	message.append(System.lineSeparator());
	message.append("If there is no such field, create one called \"unitPhase\" and make it visible on the units tab.");
	message.append(System.lineSeparator());
	message.append("Otherwise - modify the file: v3x/FieldDesigner/config/partner/LocationUnitFields.tof");
	message.append(System.lineSeparator());
	message.append("Replacing \"unitPhase\" with the existing(non-standard) field name.");
	
	JOptionPane.showMessageDialog(null, message.toString(), "Could not find unit phase field.", JOptionPane.WARNING_MESSAGE);
}

private void updateLocationUnitFieldsFile() {
	log.info("Updating LocationUnitFields.tof");
	toffy = SystemServices.vfs().fileFor("v3x/FieldDesigner/config/partner/LocationUnitFields.tof");
	fieldList = new ArrayList();
	fieldList.add("unit");
	fieldList.add("quantity");
	fieldList.add("angle");
	fieldList.add(unitPhaseFieldName);
	fieldList.add("MultiSpeak_assemblyID");
	fieldList.add("MultiSpeak_featureID");
	fieldList.add("MultiSpeak_elementID");
	TofLib.writeObjectTo(fieldList, toffy);
	log.info("Finished LocationUnitFields.tof");
}
private void addNewFieldsToTof() {
	log.info("Updating UnitFields.tof.");
	fieldDefs.putAll(newFields);
	TofLib.writeObjectTo(fieldDefs, file);
	log.info("Finished UnitFields.tof.");
}

private void addNewFieldsToDatabase() {
	log.info("Adding new unit fields to database.");
	database = new StakerConfigDatabase();	
	database.open();
	for(entry in newFields) {
		field = entry.getValue();
		if(database.stakedUnitFieldExists(entry.getKey()))
			log.info("Staked unit field: " + entry.getKey() + " already exists...");	
		else {
			log.info("Adding staked unit field: " + entry.getKey());
			database.addStakedUnitField(entry.getKey(), field.getDisplayName(), field.getDescription(), "string", null);
		}
	}
		
	log.info("Finished adding new unit fields to database.");
}

private String getUnitPhaseFieldName() {
	String defaultName = "unitPhase";
	if(fieldDefs.containsKey("phase"))
		return "phase";
	
	// if no phase field is found, flag so we can message the user.
	if(!fieldDefs.containsKey(defaultName))
		ambiguousUnitPhaseField = true;	

	return defaultName;		
}

private Naming<FieldDef> createNewFieldDefs() {
	
	assemblyFieldDef = new FieldDef();
	assemblyFieldDef.setName("MultiSpeak_assemblyID");
	assemblyFieldDef.setDisplayName("MultiSpeak_assemblyID");
	assemblyFieldDef.setDescription("GUID field for MultiSpeak GIS integration");
	assemblyFieldDef.setType(String.class);
	
	featureFieldDef = new FieldDef();
	featureFieldDef.setName("MultiSpeak_featureID");
	featureFieldDef.setDisplayName("MultiSpeak_featureID");
	featureFieldDef.setDescription("GUID field for MultiSpeak GIS integration");
	featureFieldDef.setType(String.class);
	
	elementFieldDef = new FieldDef();
	elementFieldDef.setName("MultiSpeak_elementID");
	elementFieldDef.setDisplayName("MultiSpeak_elementID");
	elementFieldDef.setDescription("GUID field for MultiSpeak GIS integration");
	elementFieldDef.setType(String.class);
	
		
	newFields = new Naming();
	newFields.put(assemblyFieldDef.getName(), assemblyFieldDef);
	newFields.put(featureFieldDef.getName(), featureFieldDef);
	newFields.put(elementFieldDef.getName(), elementFieldDef);
	
	/*
	if(ambiguousUnitPhaseField) {
		unitPhaseFieldDef = new FieldDef();
		unitPhaseFieldDef.setName("unitPhase");
		unitPhaseFieldDef.setDisplayName("Phase:");
		unitPhaseFieldDef.setDescription("Unit Phase");
		unitPhaseFieldDef.setType(org.jcon.data.PicklistItem.class);
		
		// gonna guess there is a phase picklist...
		fieldProperties = new HashMap();
		fieldProperties.put("picklist", "phase");
		
		unitPhaseFieldDef.setProperties(fieldProperties);
		newFields.put(unitPhaseFieldDef.getName(), unitPhaseFieldDef);
	}
	*/
	
	return newFields;
}
